<template>
    <div >
        <v-row>
            <v-col xs="12" sm="8" md="8" class="mt-3">
                <span class="headline">
                    {{
                        trans('messages.customer_statement', {
                            customer: customer.company,
                        })
                    }}
                </span>
            </v-col>
            <v-col xs="12" sm="4" md="4">
                <v-dialog
                  v-model="datePickerDialog"
                  persistent
                  width="290px"
                >
                    <template v-slot:activator="{ on }">
                      <v-text-field
                        v-model="dateRangeText"
                        :label="trans('messages.date_range')"
                        prepend-icon="event"
                        readonly
                        v-on="on"
                      ></v-text-field>
                    </template>
                    <v-date-picker v-model="range" scrollable range>
                      <v-spacer></v-spacer>
                      <v-btn text color="primary" @click="datePickerDialog = false">
                            {{trans('messages.close')}}
                       </v-btn>
                      <v-btn text color="primary" @click="getDateRangevalue">
                        {{trans('messages.ok')}}
                      </v-btn>
                    </v-date-picker>
                </v-dialog>
            </v-col>
        </v-row>
        <v-card elevation="4">
            <v-row dense>
                <v-col xs="12" sm="12" md="12">
                    <v-card-title class="body-1">
                        <v-spacer></v-spacer>
                        {{ business.name }} <br />
                        {{ business.tax_number }} <br />
                        {{ business.email }} <br />
                        {{ business.mobile }} <br />
                        {{ business.city }}
                        {{ business.state }} <br />
                        {{ business.country }}
                        {{ business.zip_code }}
                    </v-card-title>
                    <v-divider></v-divider>
                </v-col>
            </v-row>
            <v-container >
                <v-row dense>
                    <v-col xs="12" sm="6" md="6">
                        {{ trans('messages.to') }}: <br />
                        {{ customer.company }} <br />
                        {{ customer.email }} <br />
                        {{ customer.mobile }} <br />
                        <span v-html="customer.billing_address"></span>
                    </v-col>
                    <v-col xs="12" sm="6" md="6" class="text-right">
                        {{ trans('messages.account_summary') }} <br />
                        {{ range[0] | formatDate }} {{ trans('messages.to') }}
                        {{ range[1] | formatDate }}
                    </v-col>
                </v-row>
                <v-row dense>
                    <v-col xs="12" sm="12" md="12" class="text-center">
                        {{
                            trans('messages.showing_payments_and_invoices', {
                                start_date: $appFormatters.formatDate(range[0]),
                                end_date: $appFormatters.formatDate(range[1]),
                            })
                        }}
                    </v-col>
                </v-row>
                <v-row >
                    <v-col xs="12" sm="12" md="12">
                        <br /><br />
                        <v-row class="text-center">
                            <v-col md="2">
                                <h4>{{ trans('messages.date') }}</h4>
                            </v-col>
                            <v-col md="4">
                                <h4>{{ trans('messages.details') }}</h4>
                            </v-col>
                            <v-col md="2">
                                <h4>{{ trans('messages.amount') }}</h4>
                            </v-col>
                            <v-col md="2">
                                <h4>{{ trans('messages.payments') }}</h4>
                            </v-col>
                            <v-col md="2">
                                <h4>{{ trans('messages.balance') }}</h4>
                            </v-col>
                        </v-row>
                        <v-row class="text-center">
                            <template v-for="transaction in transactions">
                                <v-col md="2">
                                    <span>
                                        {{ transaction.transaction_date | formatDate }}
                                    </span>
                                </v-col>
                                <v-col md="4">
                                    <span v-if="transaction.type == 'invoice'">
                                        {{
                                            trans('messages.invoice_on', {
                                                ref_no: transaction.ref_no,
                                                transaction_date: transaction.transaction_date,
                                            })
                                        }}
                                    </span>
                                    <span v-if="transaction.type == 'payment'">
                                        {{
                                            trans('messages.payment_to_invoice', {
                                                ref_no: transaction.ref_no,
                                            })
                                        }}
                                    </span>
                                </v-col>
                                <v-col md="2">
                                    <span v-if="transaction.type == 'invoice'">
                                        {{ transaction.total | formatMoney(currency.symbol) }}
                                    </span>
                                </v-col>
                                <v-col md="2">
                                    <span v-if="transaction.type == 'payment'">
                                        {{ transaction.amount | formatMoney(currency.symbol) }}
                                    </span>
                                </v-col>
                                <v-col md="2">
                                    <span v-if="transaction.type == 'invoice'">
                                        {{ transaction.total | formatMoney(currency.symbol) }}
                                    </span>
                                    <span v-if="transaction.type == 'payment'">
                                        {{ transaction.balance | formatMoney(currency.symbol) }}
                                    </span>
                                </v-col>
                            </template>
                        </v-row>
                    </v-col>
                    <br />
                </v-row>
                <v-row v-if="transactions.length == 0">
                    <v-col xs="12" class="text-center" mt-4>
                        <span class="headline">
                            {{ trans('messages.no_data_for_selected_date') }}
                        </span>
                    </v-col>
                </v-row>
                <v-row>
                    <v-col xs="12" sm="6" md="6" mt-4> </v-col>
                    <v-col xs="12" sm2 md="2" class="text-center" mt-4>
                        {{ trans('messages.balance_due') }}
                    </v-col>
                    <v-col xs="12" sm2 md="2" mt-4> </v-col>
                    <v-col xs="12" sm2 md="2" class="text-center" mt-4>
                        {{ dueBalance | formatMoney(currency.symbol) }}
                    </v-col>
                </v-row>
            </v-container>
        </v-card>
    </div>
</template>
<script>
export default {
    data() {
        const self = this;
        return {
            customer_id: null,
            customer: [],
            business: [],
            transactions: [],
            payments: [],
            currency: [],
            dueBalance: null,
            range: [
                    moment().startOf('month').format('YYYY-MM-DD'),
                    moment().endOf('month').format('YYYY-MM-DD')
                ],
            datePickerDialog: false,
        };
    },
    computed: {
        dateRangeText () {
            return this.range.join(' ~ ');
        }
    },
    mounted() {
        this.customer_id = this.$route.params.id;
        this.getLedgerDataFromApi(this.range[0], this.range[1]);
    },
    methods: {
        getDateRangevalue() {
            this.datePickerDialog = false;
            this.getLedgerDataFromApi(this.range[0], this.range[1]);
        },
        getLedgerDataFromApi(start_date, end_date) {
            const self = this;
            axios
                .get('/admin/customer-account-ledger', {
                    params: {
                        customer_id: self.customer_id,
                        start_date: start_date,
                        end_date: end_date,
                    },
                })
                .then(function(response) {
                    self.customer = response.data.customer;
                    self.currency = response.data.customer.currency;
                    self.business = response.data.business_info;
                    self.transactions = response.data.transactions;
                    self.dueBalance = self.getDueBlance(response.data.transactions);
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        getDueBlance(transactions) {
            var total = 0;
            var paid = 0;
            var due = 0;

            _.forEach(transactions, function(transaction) {
                if (transaction.type == 'invoice') {
                    total = _.add(total, parseFloat(transaction.total));
                } else if (transaction.type == 'payment') {
                    paid = _.add(paid, parseFloat(transaction.amount));
                }
            });

            due = _.subtract(total, paid);

            return _.floor(due, 2);
        },
    },
};
</script>
